Stan Math Library: stan/math/prim/scal/meta/return_type.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

return_type.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_META_RETURN_TYPE_HPP
2 #define STAN_MATH_PRIM_SCAL_META_RETURN_TYPE_HPP
3
4 #include <stan/math/prim/scal/meta/scalar_type.hpp>
5 #include <boost/math/tools/promotion.hpp>
6
7 namespace stan {
8
13 template <typename T1,
14 typename T2 = double,
15 typename T3 = double,
16 typename T4 = double,
17 typename T5 = double,
18 typename T6 = double>
19 struct return_type {
20 typedef typename
21 boost::math::tools::promote_args<typename scalar_type<T1>::type,
22 typename scalar_type<T2>::type,
23 typename scalar_type<T3>::type,
24 typename scalar_type<T4>::type,
25 typename scalar_type<T5>::type,
26 typename scalar_type<T6>::type>::type
27 type;
28 };
29
30 }
31 #endif
32
stan
Definition: log_sum_exp.hpp:8
stan::return_type
Metaprogram to calculate the base scalar return type resulting from promoting all the scalar types of...
Definition: return_type.hpp:19
stan::scalar_type::type
scalar_type_helper< is_vector< T >::value, T >::type type
Definition: scalar_type.hpp:35
stan::return_type::type
boost::math::tools::promote_args< typename scalar_type< T1 >::type, typename scalar_type< T2 >::type, typename scalar_type< T3 >::type, typename scalar_type< T4 >::type, typename scalar_type< T5 >::type, typename scalar_type< T6 >::type >::type type
Definition: return_type.hpp:27
scalar_type.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.